/*
	TestStringControl.cpp
	© 1997 Vikram Kulkarni
	11/6/97 - Wrote it
	11/7/97 - Added comments

	To see what a string control does
	look at the TestStringControl app
	that should have come with this.
	
	This is a sloppy example of how to
	use a StringControl.
                                        */

#include <Application.h>
#include <Window.h>
#include <View.h>
#include <Button.h>
#include "StringControl.h"

char app_sig[] = "application/x-vvk.TestStringControl";

#define LAUNCH_NETPOS 'lnps'
#define MY_MESSAGE 'myms'
#define EMAIL_ME 'emlm'

class MyWindow;
class MyApplication;

class MyWindow : public BWindow
{
	friend class MyApplication;
	public:
		MyWindow(BRect frame)
			: BWindow(frame,  "Test String Control", B_TITLED_WINDOW, B_NOT_RESIZABLE | B_NOT_ZOOMABLE)
		{};
		
		virtual bool QuitRequested()
		{
			be_app->PostMessage(B_QUIT_REQUESTED);
			return true;
		}
		
		BView *background_view;
		BTextView *text_view;
		StringControl *about;
		StringControl *my_web_page;
		StringControl *be_web_page;
		StringControl *bug_web_page;
};

class MyApplication : public BApplication
{
	public:
		MyApplication();
		
		void MessageReceived(BMessage *msg);
		virtual void AboutRequested();
		
		MyWindow *my_window;
};

MyApplication::MyApplication()
	: BApplication(app_sig)
{
	int current_workspace_count = count_workspaces();
	BRect rect;
	rect.Set(50,50,250,200);
	my_window = new MyWindow(rect);
	
	rect = my_window->Bounds();
	my_window->background_view = new BView(rect, "Background", B_FOLLOW_ALL_SIDES, B_WILL_DRAW);
	my_window->background_view->SetViewColor(219,219,219);
	
	my_window->AddChild(my_window->background_view);

	rgb_color text_color, glow_color;

	BFont my_font( be_bold_font );
	my_font.SetSize(25);	

	rect = my_window->background_view->Bounds();
	rect.top += 5;
	rect.bottom = rect.top + 15;
	rect.left += 5;
	rect.right -= 5;
	my_window->about = new StringControl(rect, "Button", "About", new BMessage(B_ABOUT_REQUESTED), NULL, NULL, &my_font);
	my_window->background_view->AddChild(my_window->about);
	my_window->about->ResizeToPreferred();
	my_window->about->SetTarget(this);
	
	text_color.red = 255;
	text_color.green = 0;
	text_color.blue = 0;
	glow_color.red = 255;
	glow_color.green = 255;
	glow_color.blue = 0;
	BMessage urlmsg(LAUNCH_NETPOS);
	urlmsg.AddString("URL", "http://www.uiuc.edu/ph/www/vkulkarn/");
	rect.top = rect.bottom + 20;
	rect.bottom = rect.top + 15;
	my_window->my_web_page = new StringControl(rect, "string_control", "http://www.uiuc.edu/ph/www/vkulkarn/", new BMessage(&urlmsg));
	my_window->background_view->AddChild(my_window->my_web_page);
	my_window->my_web_page->ResizeToPreferred();
	my_window->my_web_page->SetTarget(this);
	
	text_color.red = 255;
	text_color.green = 0;
	text_color.blue = 0;
	glow_color.red = 255;
	glow_color.green = 255;
	glow_color.blue = 0;
	urlmsg.ReplaceString("URL", "http://www.be.com");
	rect.top = rect.bottom + 5;
	rect.bottom = rect.top + 15;
	my_window->be_web_page = new StringControl(rect, "string_control2", "http://www.be.com/", new BMessage(&urlmsg), &glow_color, &text_color, be_fixed_font);
	my_window->background_view->AddChild(my_window->be_web_page);
	my_window->be_web_page->ResizeToPreferred();
	my_window->be_web_page->SetTarget(this);

	text_color.red = 255;
	text_color.green = 0;
	text_color.blue = 255;
	glow_color.red = 0;
	glow_color.green = 255;
	glow_color.blue = 0;
	urlmsg.ReplaceString("URL", "http://www.acm.uiuc.edu/bug/");
	rect.top = rect.bottom + 5;
	rect.bottom = rect.top + 15;
	my_window->bug_web_page = new StringControl(rect, "string_control3", "http://www.acm.uiuc.edu/bug", new BMessage(&urlmsg), &glow_color, &text_color, be_bold_font);
	my_window->background_view->AddChild(my_window->bug_web_page);
	my_window->bug_web_page->ResizeToPreferred();
	my_window->bug_web_page->SetTarget(this);
	
	rect.top = rect.bottom + 10;
	rect.bottom = rect.top + 45;
	BRect textrect = rect;
	textrect.OffsetTo(0,0);
	my_window->text_view = new BTextView(rect, "textview", textrect, B_FOLLOW_LEFT_RIGHT | B_FOLLOW_BOTTOM, B_WILL_DRAW);
	my_window->text_view->Insert("Move mouse over the lines above and click on them to see what a StringControl does.");
	my_window->text_view->MakeEditable(false);
	my_window->text_view->MakeSelectable(false);
	my_window->text_view->SetViewColor(219,219,219);
	my_window->background_view->AddChild(my_window->text_view);
	
	my_window->Show();	
}

void MyApplication::MessageReceived(BMessage *msg)
{
	switch(msg->what)
	{
		case LAUNCH_NETPOS:
		{
			BMimeType mt("text/html");
			char * browser_sig = NULL;
			mt.GetPreferredApp(browser_sig);
			
			BMessage urlmsg( B_ARGV_RECEIVED );
			urlmsg.AddString( "argv", "" );
			urlmsg.AddString( "argv", msg->FindString("URL") );
			urlmsg.AddInt32(  "argc", 2 );
			
			if (!browser_sig)
				browser_sig = "application/x-vnd.Be-NPOS";
			
			// launch
			BMessenger messenger( browser_sig, -1, NULL );
			if ( messenger.IsValid() ) {
				messenger.SendMessage(&urlmsg);
			} else {
				be_roster->Launch( browser_sig, &urlmsg );
			}
			break;
		}
		
		case EMAIL_ME:
		{
			BMimeType mt("text/x-email");
			char * emailapp_sig = NULL;
			mt.GetPreferredApp(emailapp_sig);
			
			if (!emailapp_sig)
				emailapp_sig = "application/x-vnd.Be-MAIL";
			
			BMessage emailmsg( B_ARGV_RECEIVED );
			emailmsg.AddString( "argv", "" );
			emailmsg.AddString( "argv", msg->FindString("EmailWho") );
			emailmsg.AddInt32 ( "argc", 2 );

			// launch
			BMessenger messenger( emailapp_sig, -1, NULL );
			if ( messenger.IsValid() ) {
				messenger.SendMessage(&emailmsg);
			} else {
				be_roster->Launch( emailapp_sig, &emailmsg );
			}
			break;
		}
		
		default:
		{
			BApplication::MessageReceived(msg);
			break;
		}
	}
}

void MyApplication::AboutRequested()
{
		BWindow		*about_window;
		BRect frame(0,0,300,200);
		about_window = new BWindow(frame,  "About", B_TITLED_WINDOW, B_NOT_RESIZABLE | B_NOT_ZOOMABLE);
		
		BView *background = new BView(frame, "Background", B_FOLLOW_ALL_SIDES, B_WILL_DRAW);
		background->SetViewColor(219,219,219);
		about_window->AddChild(background);

		frame.left += 10;
		frame.right -= 170;
		frame.top += 5;
		frame.bottom -= 150;
		BRect textframe = frame;
		textframe.OffsetTo(0,0);
		BTextView *text_view = new BTextView(frame, "TextView", textframe, B_FOLLOW_ALL_SIDES, B_WILL_DRAW);
		text_view->SetTabWidth(10);
		text_view->SetViewColor(219, 219, 219);
		text_view->MakeEditable(false);
		text_view->MakeSelectable(false);
		text_view->Insert("String Control\n");
		text_view->Insert("© 1997 Vikram Kulkarni\n");
		text_view->Insert("All Rights Reserved\n\n");
		background->AddChild(text_view);

		frame.right += 160;
		frame.top = frame.bottom + 10;
		frame.bottom += 75;
		textframe = frame;
		textframe.OffsetTo(0,0);
		BTextView *text_view_two = new BTextView(frame, "TextViewTwo", textframe, B_FOLLOW_ALL_SIDES, B_WILL_DRAW);
		text_view_two->SetTabWidth(10);
		text_view_two->SetViewColor(219, 219, 219);
		text_view_two->MakeEditable(false);
		text_view_two->MakeSelectable(false);
		text_view_two->Insert("String Control is email ware.  Please mention me if you\nuse it in you app.\n");
		text_view_two->Insert("			-Vik\n\n");
		text_view_two->Insert("And try out these web sites while you're online:\n");
		background->AddChild(text_view_two);

		BMessage urlmsg(LAUNCH_NETPOS);
		urlmsg.AddString("URL", "http://www.uiuc.edu/ph/www/vkulkarn/");
		frame.top = frame.bottom + 2;
		StringControl *my_web_page = new StringControl(frame, "mywebpage", "http://www.uiuc.edu/ph/www/vkulkarn/", new BMessage(&urlmsg));
		my_web_page->ResizeToPreferred();
		background->AddChild(my_web_page);
		my_web_page->SetTarget(be_app);

		frame.top = frame.bottom + 16;
		urlmsg.ReplaceString("URL", "http://www.acm.uiuc.edu/bug/");
		StringControl *bug_web_page = new StringControl(frame, "bugwebpage", "http://www.acm.uiuc.edu/bug/", new BMessage(&urlmsg));
		bug_web_page->ResizeToPreferred();
		background->AddChild(bug_web_page);
		bug_web_page->SetTarget(be_app);

		frame.top = frame.bottom + 30;
		urlmsg.ReplaceString("URL", "http://www.cen.uiuc.edu/~vansloot/");
		StringControl *stool_web_page = new StringControl(frame, "stoolwebpage", "http://www.cen.uiuc.edu/~vansloot/", new BMessage(&urlmsg));
		stool_web_page->ResizeToPreferred();
		background->AddChild(stool_web_page);
		stool_web_page->SetTarget(be_app);

		frame.Set(123,16, 150,150);
		BMessage emailmsg(EMAIL_ME);
		emailmsg.AddString("EmailWho", "mailto:vkulkarn@uiuc.edu");
		StringControl *email= new StringControl(frame, "email", "(vkulkarn@uiuc.edu)", new BMessage(&emailmsg));
		email->ResizeToPreferred();
		background->AddChild(email);
		email->SetTarget(be_app);

		BFont font(be_bold_font);
		font.SetSize(18);
		frame = background->Bounds();
		StringControl *quit_button = new StringControl(frame, "quit_button", "Okay", new BMessage(B_QUIT_REQUESTED), NULL, NULL, &font);
		float width = 0.0, height = 0.0;
		quit_button->GetPreferredSize(&width, &height);
		quit_button->MoveTo(frame.Width() - width - 5, frame.Height() - height - 5);
		quit_button->ResizeToPreferred();
		background->AddChild(quit_button);
		

		about_window->MoveTo(100,100);
		about_window->Show();
}

int main()
{
	MyApplication *app = new MyApplication();
	app->Run();
}
